Enum bilrost_types::Value

source ·
pub enum Value {
    Null,
    Float(f64),
    Signed(i64),
    Unsigned(u64),
    String(String),
    Bool(bool),
    Struct(StructValue),
    List(ListValue),
}
Value represents a dynamically typed value which can be either null, a number, a string, a boolean, a recursive struct value, or a list of values. A producer of value is expected to set one of these variants.

The JSON representation for Value is JSON value.

Variants



Null

Represents a JSON null value.



Float(f64)



Signed(i64)



Unsigned(u64)



String(String)



Bool(bool)



Struct(StructValue)

Represents a structured value.



List(ListValue)

Represents a repeated Value.