Struct bilrost_types::StructValue

source ·
pub struct StructValue {
    pub fields: BTreeMap<String, Value>,
}
Struct represents a structured data value, consisting of fields which map to dynamically typed values. In some languages, Struct might be supported by a native representation. For example, in scripting languages like JS a struct is represented as an object. The details of that representation are described together with the proto support for the language.

The JSON representation for Struct is JSON object.

Fields

fields: BTreeMap<String, Value>

Unordered map of dynamically typed values.