Struct bilrost_types::Value
source · pub struct Value {
pub kind: Kind,
}Expand description
Value represents a dynamically typed value which can be either
null, a number, a string, a boolean, a recursive struct value, or a
list of values. A producer of value is expected to set one of these
variants. Absence of any variant indicates an error.
The JSON representation for Value is JSON value.
Fields
kind: KindThe kind of value. None represents JSON null.